searchData={"items":[{"type":"module","title":"Ensemble","doc":"Test LiveView with ARIA roles.\n\nIf you are new to the concepts of accessible names or roles I recommend reading W3C’s guides:\n\n- [Landmark roles](https://www.w3.org/WAI/ARIA/apg/practices/landmark-regions/)\n- [Structual content roles](https://www.w3.org/WAI/ARIA/apg/practices/structural-roles/)\n- [Accessible names](https://www.w3.org/WAI/ARIA/apg/practices/names-and-descriptions/)\n\nNote: Ensemble has only a partial implementation of the accessible name algorithm, specifically it supports `aria-label` and descendant content but does not yet support `aria-labelledby` due to the constraints of selectors.","ref":"Ensemble.html"},{"type":"function","title":"Ensemble.has_role?/3","doc":"Checks if the given element with `role` (and optional [accessible name](https://www.w3.org/WAI/ARIA/apg/practices/names-and-descriptions/#whatareaccessiblenamesanddescriptions?)) exists within `view`.","ref":"Ensemble.html#has_role?/3"},{"type":"function","title":"Examples - Ensemble.has_role?/3","doc":"```elixir\ndefmodule TodoLiveTest do\n  use YourAppWeb.ConnCase, async: true\n\n  import Phoenix.LiveViewTest\n  import Ensemble\n\n  test \"has landmarks\", %{conn: conn} do\n    {:ok, view, _html} = live(conn, \"/todos\")\n\n    assert view |> has_role?(:banner)\n    assert view |> has_role?(:main)\n    assert view |> has_role?(:contentinfo)\n\n    assert view |> has_role?(:navigation, \"Primary\")\n\n    refute view |> has_role?(:link, \"Does not exist\")\n  end\nend\n```","ref":"Ensemble.html#has_role?/3-examples"},{"type":"function","title":"Ensemble.role/3","doc":"Find element with a unique `role` or accessible name combo to scope a function to.\n\nIt expects the current LiveView, a role, and an [accessible name](https://www.w3.org/WAI/ARIA/apg/practices/names-and-descriptions/#whatareaccessiblenamesanddescriptions?).","ref":"Ensemble.html#role/3"},{"type":"function","title":"Examples - Ensemble.role/3","doc":"```elixir\ndefmodule TodoLiveTest do\n  use YourAppWeb.ConnCase, async: true\n\n  import Phoenix.LiveViewTest\n  import Ensemble\n\n  test \"has landmarks and nav\", %{conn: conn} do\n    {:ok, view, _html} = live(conn, \"/todos\")\n\n    assert view |> role(:banner) |> render() =~ ~r|^  role(:main) |> render() =~ ~r|^  role(:contentinfo) |> render() =~ ~r|^  role(:navigation, \"Primary\") =~ ~r|^  role(:link, \"Home\") =~ ~r|^  role(:form) =~ ~r|^  role(:textbox, \"Email\") =~ ~r|^  role(:checkbox, \"Send newsletter\") =~ ~r|^  role(:button, \"Subscribe\") =~ ~r|^  role(:button, \"Subscribe\")\n           |> render_click() =~ \"Thanks for subscribing!\"\n  end\nend\n```","ref":"Ensemble.html#role/3-examples"},{"type":"module","title":"Ensemble.Roles","doc":"Index of ARIA roles.","ref":"Ensemble.Roles.html"},{"type":"function","title":"Ensemble.Roles.selector_for_role/1","doc":"Lookup the selector for an ARIA role.","ref":"Ensemble.Roles.html#selector_for_role/1"},{"type":"function","title":"Ensemble.Roles.selectors_for_role_named/2","doc":"Lookup the selector for an ARIA role with accessible name.","ref":"Ensemble.Roles.html#selectors_for_role_named/2"},{"type":"extras","title":"Ensemble","doc":"# Ensemble\n\n[Docs](https://hexdocs.pm/ensemble/)\n\nAn all-star cast of ARIA roles for Phoenix [LiveViewTest](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveViewTest.html).","ref":"readme.html"},{"type":"extras","title":"Installation - Ensemble","doc":"Install via [Hex](https://hex.pm/) by adding `ensemble` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ensemble, \"~> 0.0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Ensemble","doc":"Write a [LiveViewTest](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveViewTest.html) and `import Ensemble`.\n\n```elixir\ndefmodule TodoLiveTest do\n  use YourAppWeb.ConnCase, async: true\n\n  import Phoenix.LiveViewTest\n  import Ensemble\n\n  test \"has navigation\", %{conn: conn} do\n    {:ok, view, _html} = live(conn, \"/todos\")\n\n    assert view |> has_role?(:banner)\n    assert view |> has_role?(:contentinfo)\n\n    assert view |> has_role?(:navigation, \"Primary\")\n    assert view |> has_role?(:link, \"Home\")\n    assert view |> has_role?(:link, \"About\")\n    assert view |> has_role?(:button, \"Sign Out\")\n\n    refute view |> has_role?(:link, \"Does not exist\")\n\n    assert view\n           |> role(:link, \"Home\")\n           |> render() == ~S| Home |\n  end\n\n  test \"form\", %{conn: conn} do\n    {:ok, view, _html} = live(conn, \"/todos\")\n\n    assert view |> has_role?(:form, \"New item\")\n    assert view |> has_role?(:textbox, \"Description\")\n    assert view |> has_role?(:checkbox, \"High priority\")\n\n    assert view\n           |> role(:button, \"Add item\")\n           |> render_click() =~ \"Item created.\"\n  end\nend\n```","ref":"readme.html#usage"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}